# Changelog

## 2.0.0 (2025-09-16)

Full Changelog: [v0.0.2...v2.0.0](https://github.com/channel3-ai/sdk-python/compare/v0.0.2...v2.0.0)

### Features

* **api:** manual updates ([f91f4f1](https://github.com/channel3-ai/sdk-python/commit/f91f4f163ea386464efa5b307ec11b689922493e))


### Chores

* update SDK settings ([35e85c7](https://github.com/channel3-ai/sdk-python/commit/35e85c70a123d6dd8b745999388082499562347e))

## 0.0.2 (2025-09-16)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/channel3-ai/sdk-python/compare/v0.0.1...v0.0.2)

### Chores

* sync repo ([ab5e4db](https://github.com/channel3-ai/sdk-python/commit/ab5e4db3bb8b00b432e09fd05079277cad518277))
* update SDK settings ([1bdef96](https://github.com/channel3-ai/sdk-python/commit/1bdef969e22a85f658edc0f31eef8657df2b2090))
